.. _convolution:

******************************************
Convolution (`baseband_tasks.convolution`)
******************************************

`~baseband_tasks.convolution` contains tasks for convolving time streams
with a response.

.. _convolution_api:

Reference/API
=============

.. automodapi:: baseband_tasks.convolution
   :no-inherited-members:
